@@ -6,15 +6,13 @@ use solana_sdk::{account::Account, pubkey::Pubkey};
 use spl_token::state::Mint;
 use std::io::Error;
 
-pub fn get_metadata_pda(mint_pubkey: Pubkey) -> Pubkey {
-    let program_id = Pubkey::try_from(TOKEN_METADATA_PROGRAM_ID)
-        .expect("Failed to parse Token Metadata Program Id");
+pub fn get_metadata_pda(mint_pubkey: &Pubkey) -> Pubkey {
     let seeds = &[
         "metadata".as_bytes(),
-        program_id.as_ref(),
+        TOKEN_METADATA_PROGRAM_ID.as_ref(),
         mint_pubkey.as_ref(),
     ];
-    let (pubkey, _) = Pubkey::find_program_address(seeds, &program_id);
+    let (pubkey, _) = Pubkey::find_program_address(seeds, &TOKEN_METADATA_PROGRAM_ID);
     pubkey
 }
 
@@ -27,7 +25,11 @@ pub fn decode_mint_account(mint_account: &Account) -> Result<Mint, DecodeError>
     Ok(mint_data)
 }
 
-pub fn get_metadata_struct(account: &Account) -> Result<Metadata, DecodeError> {
+// pub fn decode_candy_account(candy_v1: &Account){
+//     debug_account_data(data, f);
+// }
+
+pub fn decode_metadata_account(account: &Account) -> Result<Metadata, DecodeError> {
     let account_data = account.data.as_slice();
     let metadata: Result<Metadata, Error> = try_from_slice_unchecked(account_data);
     let token_metadata = match metadata {
